@@ -7,7 +7,6 @@ Redistribution and use in source and binary forms,
 with or without modification, is strictly prohibited.
 """
 
-import logging
 from typing import List
 
 from jaxl.api.base import (
@@ -27,10 +26,13 @@ class JaxlAppStreamingSpeechSegment(BaseJaxlApp):
             num_characters=-1,
         )
 
+    async def handle_speech_detection(self, speaking: bool) -> None:
+        print("🎙️" if speaking else "🤐")
+
     async def handle_speech_segment(
         self,
         req: JaxlStreamRequest,
         slin16s: List[bytes],
     ) -> None:
-        logging.info(f"Received {len(slin16s)} chunks in speech segment")
+        print(f"Received {len(slin16s)} chunks in speech segment")
         return None
